==> open-cluster-management-operator-model-6.0.0-sources.jar: io/fabric8/openclustermanagement/api/model/operator/v1/GenerationStatusFluentImpl.java <==
package io.fabric8.openclustermanagement.api.model.operator.v1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Long;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class GenerationStatusFluentImpl<A extends GenerationStatusFluent<A>> extends BaseFluent<A> implements GenerationStatusFluent<A>{
  public GenerationStatusFluentImpl() {
  }
  public GenerationStatusFluentImpl(GenerationStatus instance) {
    this.withGroup(instance.getGroup()); 
    this.withLastGeneration(instance.getLastGeneration()); 
    this.withName(instance.getName()); 
    this.withNamespace(instance.getNamespace()); 
    this.withResource(instance.getResource()); 
    this.withVersion(instance.getVersion()); 
  }
  private String group;
  private Long lastGeneration;
  private String name;
  private String namespace;
  private String resource;
  private String version;
  public String getGroup() {
    return this.group;
  }
  public A withGroup(String group) {
    this.group=group; return (A) this;
  }
  public Boolean hasGroup() {
    return this.group != null;
  }
  public Long getLastGeneration() {
    return this.lastGeneration;
  }
  public A withLastGeneration(Long lastGeneration) {
    this.lastGeneration=lastGeneration; return (A) this;
  }
  public Boolean hasLastGeneration() {
    return this.lastGeneration != null;
  }
  public String getName() {
    return this.name;
  }
  public A withName(String name) {
    this.name=name; return (A) this;
  }
  public Boolean hasName() {
    return this.name != null;
  }
  public String getNamespace() {
    return this.namespace;
  }
  public A withNamespace(String namespace) {
    this.namespace=namespace; return (A) this;
  }
  public Boolean hasNamespace() {
    return this.namespace != null;
  }
  public String getResource() {
    return this.resource;
  }
  public A withResource(String resource) {
    this.resource=resource; return (A) this;
  }
  public Boolean hasResource() {
    return this.resource != null;
  }
  public String getVersion() {
    return this.version;
  }
  public A withVersion(String version) {
    this.version=version; return (A) this;
  }
  public Boolean hasVersion() {
    return this.version != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    GenerationStatusFluentImpl that = (GenerationStatusFluentImpl) o;
    if (group != null ? !group.equals(that.group) :that.group != null) return false;
    if (lastGeneration != null ? !lastGeneration.equals(that.lastGeneration) :that.lastGeneration != null) return false;
    if (name != null ? !name.equals(that.name) :that.name != null) return false;
    if (namespace != null ? !namespace.equals(that.namespace) :that.namespace != null) return false;
    if (resource != null ? !resource.equals(that.resource) :that.resource != null) return false;
    if (version != null ? !version.equals(that.version) :that.version != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(group,  lastGeneration,  name,  namespace,  resource,  version,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (group != null) { sb.append("group:"); sb.append(group + ","); }
    if (lastGeneration != null) { sb.append("lastGeneration:"); sb.append(lastGeneration + ","); }
    if (name != null) { sb.append("name:"); sb.append(name + ","); }
    if (namespace != null) { sb.append("namespace:"); sb.append(namespace + ","); }
    if (resource != null) { sb.append("resource:"); sb.append(resource + ","); }
    if (version != null) { sb.append("version:"); sb.append(version); }
    sb.append("}");
    return sb.toString();
  }
  
}

==> open-cluster-management-operator-model-6.7.0-sources.jar: io/fabric8/openclustermanagement/api/model/operator/v1/GenerationStatusFluentImpl.java <==
package io.fabric8.openclustermanagement.api.model.operator.v1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Long;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class GenerationStatusFluentImpl<A extends GenerationStatusFluent<A>> extends BaseFluent<A> implements GenerationStatusFluent<A>{
  public GenerationStatusFluentImpl() {
  }
  public GenerationStatusFluentImpl(GenerationStatus instance) {
    if (instance != null) {
      this.withGroup(instance.getGroup());
      this.withLastGeneration(instance.getLastGeneration());
      this.withName(instance.getName());
      this.withNamespace(instance.getNamespace());
      this.withResource(instance.getResource());
      this.withVersion(instance.getVersion());
    }
  }
  private String group;
  private Long lastGeneration;
  private String name;
  private String namespace;
  private String resource;
  private String version;
  public String getGroup() {
    return this.group;
  }
  public A withGroup(String group) {
    this.group=group; return (A) this;
  }
  public Boolean hasGroup() {
    return this.group != null;
  }
  public Long getLastGeneration() {
    return this.lastGeneration;
  }
  public A withLastGeneration(Long lastGeneration) {
    this.lastGeneration=lastGeneration; return (A) this;
  }
  public Boolean hasLastGeneration() {
    return this.lastGeneration != null;
  }
  public String getName() {
    return this.name;
  }
  public A withName(String name) {
    this.name=name; return (A) this;
  }
  public Boolean hasName() {
    return this.name != null;
  }
  public String getNamespace() {
    return this.namespace;
  }
  public A withNamespace(String namespace) {
    this.namespace=namespace; return (A) this;
  }
  public Boolean hasNamespace() {
    return this.namespace != null;
  }
  public String getResource() {
    return this.resource;
  }
  public A withResource(String resource) {
    this.resource=resource; return (A) this;
  }
  public Boolean hasResource() {
    return this.resource != null;
  }
  public String getVersion() {
    return this.version;
  }
  public A withVersion(String version) {
    this.version=version; return (A) this;
  }
  public Boolean hasVersion() {
    return this.version != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    GenerationStatusFluentImpl that = (GenerationStatusFluentImpl) o;
    if (!java.util.Objects.equals(group, that.group)) return false;

    if (!java.util.Objects.equals(lastGeneration, that.lastGeneration)) return false;

    if (!java.util.Objects.equals(name, that.name)) return false;

    if (!java.util.Objects.equals(namespace, that.namespace)) return false;

    if (!java.util.Objects.equals(resource, that.resource)) return false;

    if (!java.util.Objects.equals(version, that.version)) return false;

    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(group,  lastGeneration,  name,  namespace,  resource,  version,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (group != null) { sb.append("group:"); sb.append(group + ","); }
    if (lastGeneration != null) { sb.append("lastGeneration:"); sb.append(lastGeneration + ","); }
    if (name != null) { sb.append("name:"); sb.append(name + ","); }
    if (namespace != null) { sb.append("namespace:"); sb.append(namespace + ","); }
    if (resource != null) { sb.append("resource:"); sb.append(resource + ","); }
    if (version != null) { sb.append("version:"); sb.append(version); }
    sb.append("}");
    return sb.toString();
  }
  
}
